//******************************************************************************
//  MSP-430-Day II Demo - DMA0 Repeated Burst to-from RAM, Software Trigger
//
//  Description; A 16 word block from 220h-240h is transfered to 240h-260h
//  using DMA0 in a burst block using software DMAREQ trigger.
//  After each transfer, source, destination and DMA size are 
//  reset to inital software setting because DMA transfer mode 5 is used. 
//  P1.0 is toggled durring DMA transfer only for demonstration purposes.
//  ** RAM location 0x220 - 0x260 used - always make sure no compiler conflict **
//  ACLK = 32768, MCLK = SMCLK = default DCO =1048576
//  //*An external watch crystal on XIN XOUT is required for ACLK*//	  
//  //*MSP430FG439 Device Required*//
//
//               MSP430FG439
//            -----------------
//        /|\|              XIN|-  
//         | |                 | 32KHz
//         --|RST          XOUT|-
//           |                 |
//           |             P1.0|-->LED
//
//  M.Buccini
//  Texas Instruments, Inc
//  February 2004
//  Updated for IAR Embedded Workbench Version: 2.21B
//******************************************************************************

#include  <msp430xG43x.h>

void main(void)
{ 
  WDTCTL = WDTPW + WDTHOLD;             // Stop watchdog 
  FLL_CTL0 |= XCAP14PF;                 // Set load capacitance
  P1DIR |= 0x01;                        // P1.0 = output
  DMA0SA = 0x0220;                      // Start block address
  DMA0DA = 0x0240;                      // Destination block address
  DMA0SZ = 0x010;                       // Block size
  DMA0CTL = DMADT_5 + DMASRCINCR_3 + DMADSTINCR_3 + DMAEN; // Rpt, inc SRC, DST

  for (;;)                              // Repeat                             
  {
    P1OUT |= 0x01;                      // Set P1.0 (LED on)
    DMA0CTL |= DMAREQ;                  // Trigger block transfer
    P1OUT &= ~0x01;                     // Clear P1.0 (LED off)
    _NOP();                             // << SET BREAKPOINT HERE
  }
}
